aboutsummaryrefslogtreecommitdiff
path: root/src/nvim/buffer_defs.h
diff options
context:
space:
mode:
authorJan Edmund Lazo <jan.lazo@mail.utoronto.ca>2021-10-17 10:26:11 -0400
committerGitHub <noreply@github.com>2021-10-17 10:26:11 -0400
commita1e8199fff098e158e22e25abc20c512575c1c53 (patch)
tree360b7b51a293eb4aafa8be7b7bcdd726bf34854b /src/nvim/buffer_defs.h
parent77e6ecf85aa756ebca4548e4cfbc906bf8fff568 (diff)
parent38821cc50e7d353b7e8a372da8413e550595b734 (diff)
downloadrneovim-a1e8199fff098e158e22e25abc20c512575c1c53.tar.gz
rneovim-a1e8199fff098e158e22e25abc20c512575c1c53.tar.bz2
rneovim-a1e8199fff098e158e22e25abc20c512575c1c53.zip
Merge pull request #15952 from zeertzjq/vim-8.1.1291
vim-patch:8.0.{1459,1460,1461,1463},8.1.{0602,0604,1291},8.2.{0189,0876,0909,1411}: chdir and DirChanged related patches
Diffstat (limited to 'src/nvim/buffer_defs.h')
-rw-r--r--src/nvim/buffer_defs.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/nvim/buffer_defs.h b/src/nvim/buffer_defs.h
index 2c411553b8..19b0a3c5c6 100644
--- a/src/nvim/buffer_defs.h
+++ b/src/nvim/buffer_defs.h
@@ -953,6 +953,7 @@ struct tabpage_S {
ScopeDictDictItem tp_winvar; ///< Variable for "t:" Dictionary.
dict_T *tp_vars; ///< Internal variables, local to tab page.
char_u *tp_localdir; ///< Absolute path of local cwd or NULL.
+ char_u *tp_prevdir; ///< Previous directory.
};
/*
@@ -1381,8 +1382,8 @@ struct window_S {
// out of range!)
int w_arg_idx_invalid; // editing another file than w_arg_idx
- char_u *w_localdir; /* absolute path of local directory or
- NULL */
+ char_u *w_localdir; // absolute path of local directory or NULL
+ char_u *w_prevdir; // previous directory
// Options local to a window.
// They are local because they influence the layout of the window or
// depend on the window layout.